MotionHandle

Struct MotionHandle 

pub struct MotionHandle<T: Decompose + Send + Sync + Clone + 'static> { /* private fields */ }
All-in-one motion handle.

Implementations

Source

impl<T: Decompose + Send + Sync + Clone + 'static> MotionHandle<T>

pub fn signal(&self) -> Signal<T>

Current reactive value signal.

pub fn value(&self) -> T

Current value snapshot.

pub fn animate_to(&self, target: T, config: MotionConfig)

Animate to a target with tween or spring configuration.

pub fn spring_to(&self, target: T, config: SpringConfig)

Spring to a target.

pub fn keyframes(&self, track: KeyframeTrack<T>)

Play a keyframe track.

pub fn stop(&self)

Stop the active animation without changing the current value.

pub fn snap_to(&self, value: T)

Snap instantly to a value and stop animation.

pub fn is_animating(&self) -> bool

Returns true while an animation is active.

pub fn tick(&self, dt: f32) -> bool

Deterministically advance the active animation by dt seconds.